@@ -2,6 +2,8 @@ from enum import Enum
 
 
 class ModelType(Enum):
+    """Class that contains model types
+    """  # noqa
     TENSORFLOW = 0
     PYTORCH = 1
     SKLEARN = 2
